@@ -226,6 +226,9 @@ pub type glEnable_t = extern "system" fn(cap: GLenum);
 /// [glEnableVertexAttribArray](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glEnableVertexAttribArray.xhtml)
 pub type glEnableVertexAttribArray_t = extern "system" fn(index: GLuint);
 
+/// [glDisableVertexAttribArray](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glEnableVertexAttribArray.xhtml)
+pub type glDisableVertexAttribArray_t = extern "system" fn(index: GLuint);
+
 /// [glFramebufferRenderbuffer](https://www.khronos.org/registry/OpenGL-Refpages/gl4/html/glFramebufferRenderbuffer.xhtml)
 pub type glFramebufferRenderbuffer_t = extern "system" fn(target: GLenum, attachment: GLenum, renderbuffertarget: GLenum, renderbuffer: GLuint);
 
